#Statistical Analysis of Hard Parts data for Lyssikatos & Wenzel 2024
#Import data set 'allmeta_prey_v5.csv' from ~/mydoc/Seals/FredFiles/ML_Dissertation/Chapter 1
#It was produced in SAS ~/seasamp/biosamp/PvHg_summary_v2.sas

####################
## Load libraries ##
####################

library(dplyr); library(tidyr); library(boot); library(mgcv); library(lme4); library(AER)

rm(list=ls(all=TRUE))

## Set Working Directory ##
## Can't set a working directory that is different from the Project Directory
## The project directory is ~/Advanced Studies/UMD/Committee/Dissertation/Chapter 1
#setwd('C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1')


######################
## Read in datasets ##
######################

#version 5#
#The format is detail prey species, so all meta data is repeated for each Tagnum
#Includes both Pv and Hg stomach samples

obs = read.csv('C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/allmeta_prey_v5.csv',header=TRUE)

table(obs$guild)
table(obs$Species)

names(obs); table(obs$Species)

#Summarize data on cod see in the diet - back pocket info for DFO/US Bilateral 
#Meeting on 03Feb2023

table(obs[obs$Species=="Gadus morhua" & obs$comname=="Gray Seal",5])
table(obs[obs$Species=="Gadus morhua" & obs$comname=="Harbor Seal",5])

library(dplyr); library(tidyr) 
library(ggplot2)

#Summarize the FoO and abundance of cod in samples by predator and year
cod = obs[obs$Species=="Gadus morhua",] %>% group_by(comname,age,sex) %>%
  summarise(
    N_stomachs = n(),
    cod_mni = (sum(mni)),
    cod_kgs = (sum(wgtkg))
  )

#Summarize the FoO and abundance of sand lance in samples by predator and year
slance = obs[obs$Species=="Ammodytes",] %>% group_by(comname,age,sex) %>%
  summarise(
    N_stomachs = n(),
    sl_mni = (sum(mni)),
    sl_kgs = (sum(wgtkg))
  )
#Summarize the FoO and abundance of Haddock in samples by predator and year
haddock = obs[obs$Species=="Melanogrammus aeglefinus",] %>% group_by(comname,age,sex) %>%
  summarise(
    N_stomachs = n(),
    sl_mni = (sum(mni)),
    sl_kgs = (sum(wgtkg))
  )

#Number of stomach sample per predator
n_stomach = obs %>% group_by(comname) %>%
  summarize(count = n_distinct(Tagnum1))

#obs$epu = factor(obs$epu,levels=c('gb','gom','mab','ss'))

#Remove records with missing effort #SCHAVEZ
#obs = obs %>% filter(!is.na(dysfish))

##################################################
## Aggregate data ##
##################################################

#First eliminate records where guild = junk (i.e. Menidia menidia), empty, and Elasmob
#because they don't contribute to mni or kgs consumed

fix = obs %>% filter (guild != "Junk" & guild !="Elasmob" & guild !="Empty" & guild !="Benth/Piscv")
fix$guild <- droplevels(fix$guild)
dim(obs)
dim(fix)
table(obs$guild)
table(fix$guild)

table(fix$guild,fix$comname)

#Create box plot of kgs consumed (y) by trophic guild & predator (x), and show sample size

par(mai=c(1.75,0.82,0.82,0.42))

g <- boxplot(wgtkg ~ guild*comname, data=fix, plot=0)

boxplot(wgtkg ~ guild*comname, data=fix, main="Guild",las=2,cex.axis=0.75, ylab="KGS")

text(1:length(g$n), g$stats[5,]+5, paste("", g$n), col=4) #Puts sample size at top of whisker

#Contingency table of trophic groups FoO in seal stomach samples with
#Chi-sqare test of independence. Is there a relationship between seal species 
#and trophic groups present in stomach samples?

library(summarytools)
library(dplyr)

# fourth method from: https://statsandr.com/blog/chi-square-test-of-independence-in-r/
fix %$%
  ctable(guild,comname,
         prop = "r", chisq = TRUE, headings = FALSE
  ) %>%
  print
#(method = "render",  style = "rmarkdown", footnote = NA)

#Visualize results from contingency test of independence

# load packages
#library(ggstatsplot)
#library(ggplot2)

# plot that provides visualization (mosaic) of chi-square test

library(vcd)

mosaic(~ guild + comname,
       #direction = c("h", "v"),
       data = fix,
       shade = TRUE,
       direction = "h", rot_labels=c(0,90,0,0),
       labeling_args = list(offset_varnames = c(left = 3, top=0))
                                 
)

#ggbarstats requires version 4 and up 
ggbarstats(
  data = fix,
  x = comname,
  y = guild
) +
  labs(caption = NULL) # remove caption

#Sum mni and wgtkg over species to get sum mni, wgtkg by predator - inlcude all metadata

obs_pred = fix %>% group_by(comname,Tagnum1,tripid,negear,year,month,day,latdd,londd,
                            sar,sex,age,length,Epu,season) %>%
  summarise(
    prey = n(),
    guild_obs = n_distinct(guild),
    mni_sum = as.numeric(round(sum(mni))),
    kgs_sum = (sum(wgtkg))
  )


summary(obs_pred[,18:19])
table(obs_pred$comname)
table(obs_pred$year,obs_pred$comname)

#Sum mni and wgtkg by predator & prey to get total mni to match table 2
predprey_mni = fix %>% group_by(comname,Species) %>%
  summarise(
    mni_tot = as.numeric(round(sum(mni))),
    kgs_tot = (sum(wgtkg))
  )

#Sum mni and wgtkg total by predator to match table 2
pred_mni = predprey_mni %>% group_by(comname) %>%
  summarise(
    Tmni = as.numeric(round(sum(mni_tot))),
    Tkgs = (sum(kgs_tot))
  )

#Calculate proportion prey based on mni & kgs - by predator to match table 2
#Output to be used in calculating Proportion of dietary overlap

p_tbl2 = full_join(predprey_mni,pred_mni,by=c('comname')) %>%
  ungroup() %>%
  mutate(
    p_prey = (mni_tot / Tmni),
    p_kgs = (kgs_tot / Tkgs)
  )

#Check totals
aggregate(p_tbl2$p_prey, list(p_tbl2$comname), FUN=sum)

#Output p_tbl2 to excel. Fill in rows where only prey consumed by only on predator - needs to have duplicate
#row = where p_prey = 0 for the other predator in order for proportion overlap calculation to be correct
#because it selects minimum p_prey. Also calculate new stats to compute Horisita nich overlap index too.

#write.csv(p_tbl2, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_Overlap.csv',row.names=FALSE)

#New table for manuscript - never finished this because couldn't figure out how to 
#transpose more than one value.var - took too much time - went back over to Morisita.R script
#was quicker - and more meaningful because it computes median stats from mni and kgs summed
#for each predator stomach which is the more meaningful and correct way to inform on how
#individual seals consume on average by the various factors so go back over to that script
#for that information. Not here...

#Sum mni and wgtkg by predator & prey and 4 factors 
predprey_mnikg_epu = fix %>% group_by(guild,Species,comname,Epu) %>%
  summarise(
    #mni_tot = as.numeric(round(sum(mni))),
    #kgs_tot = (sum(wgtkg)),
    md_mni = as.numeric(round(median(mni))),
    #iqr_mni = as.numeric(round(IQR(mni))),
    q25_mni = as.numeric(round(quantile(mni,probs=0.25))),
    q75_mni = as.numeric(round(quantile(mni,probs=0.75))))
    
data.frame(predprey_mnikg_epu)
write.csv(predprey_mnikg_epu, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_newtblmnikg_epu.csv',row.names=FALSE)

library(data.table);library(reshape2)
#df_t<-transpose(predprey_mni_season)

mydt1<-dcast(predprey_mnikg_epu,guild+Species~comname+Epu,value.var="mni_tot")
mydt1[is.na(mydt1)]<-0

mydt2<-dcast(predprey_mnikg_epu,guild+Species~comname+Epu,value.var="kgs_tot")
mydt2[is.na(mydt2)]<-0

mydt3<-dcast(predprey_mnikg_epu,guild+Species~comname+Epu,value.var="md_mni")
mydt3[is.na(mydt3)]<-0

write.csv(mydt3, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_mdmni_epu.csv',row.names=FALSE)

mydt4<-dcast(predprey_mnikg_epu,guild+Species~comname+Epu,value.var="q25_mni")
mydt4[is.na(mydt4)]<-0

write.csv(mydt4, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHg_q25mni_epu.csv',row.names=FALSE)


mydt5<-dcast(predprey_mnikg_epu,guild+Species~comname+Epu,value.var="q75_mni")
mydt5[is.na(mydt5)]<-0

new_tbl_mni = full_join(mydt3,mydt4,by=c('guild','Species')) %>%
  ungroup() %>%
  mutate(
  )

#Check totals
aggregate(fix$mni, list(fix$comname,fix$Epu,fix$season), FUN=median)

junk = fix %>% group_by(guild,Species,comname,Epu) %>%
  summarise(
    md_mni = as.numeric(round(median(mni))),
    q25_mni = as.numeric(round(quantile(mni,probs=0.25))),
    q75_mni = as.numeric(round(quantile(mni,probs=0.75))))

mydt6<-as.data.table(junk,guild+Species~comname+Epu)

junk2<-melt(junk, value.name = c("q25_mni","q75_mni"))

#Contingency table of the number of trophic groups present in individual stomach samples with
#Chi-sqare test of independence. Is there a relationship between seal species 
#the # of trophic groups present in stomach samples?

# fourth method from: https://statsandr.com/blog/chi-square-test-of-independence-in-r/

# first filter out guild_obs=5 because has zero observations for gray seal - causes problems for
# chi-sq approximation

fix_nguild = obs_pred %>% filter (guild_obs < 5)
#fix_nguild <- droplevels(fix_nguild$guild_obs)
dim(fix_nguild)
table(fix_nguild$guild_obs)

fix_nguild %$%
  ctable(guild_obs,comname,
         prop = "r", chisq = TRUE, headings = FALSE
  ) %>%
  print

#Contingency table of the number of prey species present in individual stomach samples with
#Chi-sqare test of indepeddence. Is there a relationship between seal species 
#the # of prey species present in stomach samples?

# first filter out prey = 8 or 9 due to small sample sizes - causes problems for
# chi-sq approximation

fix_nspp = obs_pred %>% filter (prey < 8)

table(fix_nspp$prey)

fix_nspp %$%
  ctable(prey,comname,
         prop = "r", chisq = TRUE, headings = FALSE
  ) %>%
  print

#(method = "render",  style = "rmarkdown", footnote = NA)

#Visualize results from contingency test of independence

# load packages
#library(ggstatsplot)
#library(ggplot2)

# plot
library(vcd)

mosaic(~ guild_obs + comname,
       #direction = c("h", "v"),
       data = obs_pred,
       shade = TRUE,
       direction = "h", rot_labels=c(0,90,0,0),
       labeling_args = list(offset_varnames = c(left = 2, top=0))
       
)

#ggbarstats requires version 4 and up 
ggbarstats(
  data = fix,
  x = comname,
  y = guild
) +
  labs(caption = NULL) # remove caption


chi.guildobs<-table(obs_pred$guild_obs,obs_pred$comname)
#chisq.test(chi.guildobs, correct=FALSE)

table(obs_pred$comname)

#Compute Shannon Weiner Diversity index for each stomach sample

p = full_join(fix,obs_pred,by=c('comname','Tagnum1','tripid','negear','year','month','day','latdd','londd',
                            'sar','sex','age','length','Epu','season')) %>%
  ungroup() %>%
  mutate(
    p_prey = (mni / mni_sum),
    lp_prey = log(p_prey),
    p_lp = (p_prey*lp_prey)
    )

#look for p_prey = 0
length(which(p[,25]==0))
#look for p_lp = 0
length(which(p[,27]==0))
#look for guild = empty
length(which(p[,17]=="Empty"))

#Left off here Wednesday night - falling asleep at my computer


#Replace Nan with 0 because the sum of p_lp returns Nan and diveristy index can't be calculated for
#stomach samples where p_lp and stomachs not empty

fixp=p
fixp$p_lp[is.nan(fixp$p_lp)]<-0

length(which(fixp[,27]==0))
#table(is.na(obs_pred.v2[,21]))

obs_pred.v3 = fixp %>% group_by(comname,Tagnum1,tripid,negear,year,month,day,latdd,londd,
                            sar,sex,age,length,Epu,season,prey,guild_obs,mni_sum,kgs_sum) %>%
    summarise(
    h_product=sum(p_lp) 
    )

obs_pred.v3$H=obs_pred.v3$h_product*-1/log(obs_pred.v3$prey) #See Krebs 1999, Chpt 14, page 606)

#look for h_product = 0
length(which(obs_pred.v3[,21]=="NaN"))

#Look for prey = 1, when log prey=1 results in NaN for diversity index where h_product = 0
length(which(obs_pred.v3[,16]==1))
length(which(obs_pred.v3[,18]==1))

#Replace H' = NaN with zero. 
#There are 25 singlentons. That means stomach samples with only one fish present in the stomach
#This is different from when prey = 1 of which there are 58 and 38 of them have mni > 1 so more than one
#fish present in the stomach. 
#For H' can't divide by log of 1 so these stomachs have NaN for diveristy
#The models are kicking these out which is eliminationg too many records

obs_pred.v3$H[is.nan(obs_pred.v3$H)]<-0
length(which(obs_pred.v3[,21]==0))

table(obs_pred.v3$H,obs_pred.v3$comname)

#Histogram of H' index
hist(obs_pred.v3$H[obs_pred$comname=="Harbor Seal"],xlab = "Harbor Seal",main = "Shannon-Weiner H'")
hist(obs_pred.v3$H[obs_pred$comname=="Gray Seal"],xlab = "Gray Seal",main = "Shannon-weiner H'")

mean(obs_pred.v3$H)
grouped_data <-group_by(obs_pred.v3, comname) 
grouped_data <-group_by(obs_pred.v3, comname,age)
grouped_data <-group_by(obs_pred.v3, comname,sex) 
grouped_data <-group_by(obs_pred.v3, comname,Epu) 
mean_H <- summarize(grouped_data, means=mean(H)) 

#Plots of diet diversity as a funtion of predator and other covariates
coplot(H ~ age | comname, data=obs_pred.v3, rows=2)
coplot(H ~ age | comname, data=obs_pred.v3,rows=1)

coplot(H ~ londd | comname, data=obs_pred.v3, rows=2)
coplot(H ~ londd | comname, data=obs_pred.v3,rows=1)

par(mfrow=c(2,2)) #page will have 2 row with 2 columns

#Calculate index of importance - Iimp (Garcia_Rodrquez & Gamboa 2004)

obs_Iimp = fixp %>% group_by(comname,Species) %>%
  summarise(
    N = n(),
    p_prey_sum = (sum(p_prey))
  )

#Calculate index of importance - stratified by season
obs_Iimp_s = fixp %>% group_by(comname,season,Species) %>%
  summarise(
    N = n(),
    p_prey_sum = (sum(p_prey))
  )

#Calculate index of importance - stratified by Epu
obs_Iimp_a = fixp %>% group_by(comname,Epu,Species) %>%
  summarise(
    N = n(),
    p_prey_sum = (sum(p_prey))
  )

#Calculate index of importance - stratified by Age
obs_Iimp_age = fixp %>% group_by(comname,age,Species) %>%
  summarise(
    N = n(),
    p_prey_sum = (sum(p_prey))
  )

#Calculate index of importance - stratified by Sex
obs_Iimp_sex = fixp %>% group_by(comname,sex,Species) %>%
  summarise(
    N = n(),
    p_prey_sum = (sum(p_prey))
  )

#write.csv(obs_Iimp, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHgiimp.csv',row.names=FALSE)

#Calculated Iimp in excel to double check calculations - ~/mydoc/Seals/FredFiles/ML_Dissertation/Chapter 1
#PvHgiimp_v2.xlsx

obs_Iimp$U=NA
new =  obs_Iimp %>% mutate(.,U=ifelse(is.na(U) & (comname %in% c('Gray Seal')),143,U),
                     U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')),144,U))

Iimp_t = new %>% group_by(comname,Species) %>%
  summarise(
    iimp=1/U*(p_prey_sum)
  )

#Check totals - not stratified by season
aggregate(Iimp_t$iimp, list(Iimp_t$comname), FUN=sum)

#Calculate Iimp by predator, season and prey species

obs_Iimp_s$U=NA
table(obs_pred.v3$comname,obs_pred.v3$season)

new_s =  obs_Iimp_s %>% mutate(.,U=ifelse(is.na(U) & (comname %in% c('Gray Seal') 
                                                    & season %in% c('fall')),10,U),
                               U=ifelse(is.na(U) & (comname %in% c('Gray Seal')
                                                    & season %in% c('spring')),88,U),
                               U=ifelse(is.na(U) & (comname %in% c('Gray Seal')
                                                    & season %in% c('summer')),17,U),
                               U=ifelse(is.na(U) & (comname %in% c('Gray Seal')
                                                    & season %in% c('winter')),28,U),
                               U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                    & season %in% c('fall')),43,U),
                               U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                    & season %in% c('spring')),9,U),
                               U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                    & season %in% c('summer')),51,U),
                               U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                    & season %in% c('winter')),41,U))


Iimp_s = new_s %>% group_by(comname,season,Species) %>%
  summarise(
    iimp=1/U*(p_prey_sum)
  )

#Check totals - stratified by season
aggregate(Iimp_s$iimp, list(Iimp_s$comname,Iimp_s$season), FUN=sum)

write.csv(Iimp_s, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHgiimp_s.csv',row.names=FALSE)

#Calculate Iimp by predator, Epu and prey species
obs_Iimp_a$U=NA
table(obs_pred.v3$comname,obs_pred.v3$Epu)

new_a =  obs_Iimp_a %>% mutate(.,U=ifelse(is.na(U) & (comname %in% c('Gray Seal') 
                                                      & Epu %in% c('gb')),12,U),
                               U=ifelse(is.na(U) & (comname %in% c('Gray Seal')
                                                    & Epu %in% c('gom')),36,U),
                               U=ifelse(is.na(U) & (comname %in% c('Gray Seal')
                                                    & Epu %in% c('mab')),95,U),
                               U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                    & Epu %in% c('gom')),106,U),
                               U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                    & Epu %in% c('mab')),38,U))
                               

Iimp_a = new_a %>% group_by(comname,Epu,Species) %>%
  summarise(
    iimp=1/U*(p_prey_sum)
  )

#Calculate Iimp by predator, Age and prey species
obs_Iimp_age$U=NA
table(obs_pred.v3$comname,obs_pred.v3$age)

new_age =  obs_Iimp_age %>% mutate(.,U=ifelse(is.na(U) & (comname %in% c('Gray Seal') 
                                                      & age %in% c('adu')),7,U),
                               U=ifelse(is.na(U) & (comname %in% c('Gray Seal')
                                                    & age %in% c('juv')),15,U),
                               U=ifelse(is.na(U) & (comname %in% c('Gray Seal')
                                                    & age %in% c('pup')),18,U),
                               U=ifelse(is.na(U) & (comname %in% c('Gray Seal')
                                                    & age %in% c('unk')),2,U),
                               U=ifelse(is.na(U) & (comname %in% c('Gray Seal')
                                                    & age %in% c('yoy')),101,U),
                               U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                    & age %in% c('adu')),4,U),
                               U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                    & age %in% c('juv')),2,U),
                               U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                    & age %in% c('pup')),31,U),
                               U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                    & age %in% c('unk')),7,U),
                               U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                    & age %in% c('yoy')),100,U))


Iimp_age = new_age %>% group_by(comname,age,Species) %>%
  summarise(
    iimp=1/U*(p_prey_sum)
  )

#Calculate Iimp by predator, Sex and prey species
obs_Iimp_sex$U=NA
table(obs_pred.v3$comname,obs_pred.v3$sex)
table(obs_pred.v3$age,obs_pred.v3$sex)

new_sex =  obs_Iimp_sex %>% mutate(.,U=ifelse(is.na(U) & (comname %in% c('Gray Seal') 
                                                          & sex %in% c('.')),3,U),
                                   U=ifelse(is.na(U) & (comname %in% c('Gray Seal')
                                                        & sex %in% c('F')),62,U),
                                   U=ifelse(is.na(U) & (comname %in% c('Gray Seal')
                                                        & sex %in% c('M')),78,U),
                                   U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                        & sex %in% c('.')),6,U),
                                   U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                        & sex %in% c('F')),53,U),
                                   U=ifelse(is.na(U) & (comname %in% c('Harbor Seal')
                                                        & sex %in% c('M')),85,U))
                                   

Iimp_sex = new_sex %>% group_by(comname,sex,Species) %>%
  summarise(
    iimp=1/U*(p_prey_sum)
  )

#Check totals - stratified by Sex
aggregate(Iimp_sex$iimp, list(Iimp_sex$comname,Iimp_sex$sex), FUN=sum)

write.csv(Iimp_sex, 'C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/PvHgiimp_sex.csv',row.names=FALSE)

#Horizontal bar plots of Iimp by various factors

library(tidyr) 
library(ggplot2)
df=as.data.frame(Iimp_sex) #Iimp by sex

plot.new()

h_line=0.033

q = ggplot(data=df[df$sex!=".",], aes(x=Species, y=iimp, fill=comname)) +
  coord_flip() + #horizontal bar plot +
  geom_bar(stat="identity", width=0.75, position="dodge", show.legend=FALSE) +
  scale_fill_manual(values=c("gray","brown")) +
  theme_light() +
  facet_grid(cols=vars(sex)) +
  theme(legend.position="top", axis.text = element_text(size=6), axis.title.y = element_blank()) +
  geom_hline(aes(yintercept=h_line))

ggsave(plot=q, width = 7, height = 10, dpi=300, filename = "testsize_r.pdf")

library(tidyr) 
library(ggplot2)
df=as.data.frame(Iimp_age) #Iimp by Age

plot.new()

#h_line=0.033

z = ggplot(data=df[df$age!="unk",], aes(x=Species, y=iimp, fill=comname)) +
  coord_flip() + #horizontal bar plot +
  geom_bar(stat="identity", width=0.75, position="dodge", show.legend=FALSE) +
  scale_fill_manual(values=c("gray","brown")) +
  theme_light() +
  facet_grid(cols=vars(age)) +
  theme(legend.position="top", axis.text = element_text(size=6), axis.title.y = element_blank())
  #geom_hline(aes(yintercept=h_line))

ggsave(plot=z, width = 7, height = 10, dpi=300, filename = "testage_r.pdf")

library(tidyr) 
library(ggplot2)
df=as.data.frame(Iimp_a) #Iimp by area

plot.new()

#h_line=0.033

y = ggplot(data=df[df$Epu!=" ",], aes(x=Species, y=iimp, fill=comname)) +
  coord_flip() + #horizontal bar plot +
  geom_bar(stat="identity", width=0.75, position="dodge", show.legend=FALSE) +
  scale_fill_manual(values=c("gray","brown")) +
  theme_light() +
  facet_grid(cols=vars(Epu)) +
  theme(legend.position="top", axis.text = element_text(size=6), axis.title.y = element_blank())
#geom_hline(aes(yintercept=h_line))

ggsave(plot=y, width = 7, height = 10, dpi=300, filename = "testepu_r.pdf")

library(tidyr) 
library(ggplot2)
df=as.data.frame(Iimp_s) #Iimp by season

#Re-Order seasons so they plot across a sequential calendar
df$season<-ordered(Iimp_s$season, levels = c("winter","spring","summer","fall"))

plot.new()

#h_line=0.033

y = ggplot(data=df[df$season!=" ",], aes(x=Species, y=iimp, fill=comname)) +
  coord_flip() + #horizontal bar plot +
  geom_bar(stat="identity", width=0.75, position="dodge", show.legend=FALSE) +
  scale_fill_manual(values=c("gray","brown")) +
  theme_light() +
  facet_grid(cols=vars(season)) + geom 
  #annotate(geom = "text", y = 0.35, x = "Tautoga onitis", label = "n=10") +
  theme(legend.position="top", axis.text = element_text(size=6), axis.title.y = element_blank())
#geom_hline(aes(yintercept=h_line))

ggsave(plot=y, width = 7, height = 10, dpi=300, filename = "testseason_r.pdf")
######################################################################################
#Caluclate Percentage Overlaps (aka Schoener Overlap Index - Krebs 3rd draft ed. 2017)
#Version 2 of p_tbl2 that has added rows

p_tbl2_v2 = read.csv('C:/Users/marjorie.lyssikatos/Documents/Seals/FredFiles/ML_Dissertation/Chapter 1/p_tbl2_v2.csv',header=TRUE)

p_overlap = p_tbl2_v2 %>% group_by(Species) %>%
  summarise(
    min_preyP = (min(p_prey))
  )

#Proportion dietary overlap
sum(p_overlap$min_preyP)

#Morisita index of trophic niche overlap - overall and by season and Epu
#Calculations are in ~/mydoc/Seals/FredFiles/ML_Dissertation/Chapter 1/'Morisita_PvHg_Overlap.xlsx'
#Moristia index = 0.547 vs. Proportion dietary overlap = 0.4199

#Also see - Morisita_index.R script for calculations

#################################################################################################

## Below are exploraty plots of mni and biomass consumed as a function of covariates
## Followed by models

#Histograms of abundance and biomass consumed by predator - non-transformed
hist(obs_pred.v3$mni_sum[obs_pred$comname=="Harbor Seal"],xlab = "Harbor Seal",main = "mni")
hist(obs_pred.v3$mni_sum[obs_pred$comname=="Gray Seal"],xlab = "Gray Seal",main = "mni")
hist(obs_pred.v3$kgs_sum[obs_pred$comname=="Harbor Seal"],xlab = "Harbor Seal",main = "kgs")
hist(obs_pred.v3$kgs_sum[obs_pred$comname=="Gray Seal"],xlab = "Gray Seal",main = "kgs")

attributes(obs_pred.v3)

meta=as.data.frame(obs_pred.v3[,c(1:17,21)]) #subset metadata variables only
trsfm.mni.kgs=(as.data.frame(log(obs_pred.v3[,18:19]+1))) #log transform mni & kgs to normalize distribution
new_obs_pred=cbind(meta,trsfm.mni.kgs) #combine meta data variables with log transformed mni & Kgs

#Histograms of abundance and biomass - non-transformed & transformed
#plot.new()

par(mfrow=c(2,2))
hist(obs_pred.v3$mni_sum,freq=FALSE)
hist(obs_pred.v3$kgs_sum)
hist(obs_pred.v3$H)
hist(new_obs_pred$mni_sum)
hist(new_obs_pred$kgs_sum)

#Histogram of log transformed mni and wgtkg for each predator seperately
#hist(new_obs_pred$mni_sum[new_obs_pred$comname=="Harbor Seal"],xlab = "Harbor Seal",main = "log(mni)")
#hist(new_obs_pred$mni_sum[new_obs_pred$comname=="Gray Seal"],xlab = "Gray Seal",main = "log(mni)")
#hist(new_obs_pred$kgs_sum[new_obs_pred$comname=="Harbor Seal"],xlab = "Harbor Seal",main = "log(kgs)")
#hist(new_obs_pred$kgs_sum[new_obs_pred$comname=="Gray Seal"],xlab = "Gray Seal",main = "log(kgs)")

####################################
#Evaluate overdispersion in the data

summary(obs_pred.v3)
head(obs_pred.v3)

#boxplot(as.data.frame(sub.hg.prey.data.mo3[,2:12]), cex.axis=0.75,las=2, main="Hg Stomach Prey")
plot.new()
par(mfrow=c(2,2))

boxplot(obs_pred.v3[,18],cex.axis=0.75,las=2, main="Seal Consumption - MNI")

boxplot(obs_pred.v3[,19],cex.axis=0.75,las=2, main="Seal Consumption - KGS")

boxplot(new_obs_pred[,18],cex.axis=0.75,las=2, main="Seal Consumption - MNI")

boxplot(new_obs_pred[,19],cex.axis=0.75,las=2, main="Seal Consumption - KGS")

#Order months so they plot in sequential order
obs_pred.v3$month<-ordered(obs_pred$month, levels = c("1","2","3","4","5",
                                                   "6","7","8","9","10",
                                                   "11","12"))

# Add sample size to box plots
#Do the boxplot but do not show it
b <- boxplot(mni_sum ~ month, data=obs_pred.v3, plot=0)


boxplot(mni_sum ~ month, data=obs_pred.v3, xlab="Month",las=2,cex.axis=0.75)


text(1:length(b$n), b$stats[5,]+1, paste("", b$n)) #Puts sample size at top of whisker

# Now b$n holds the counts for each factor, we're going to write them in names
par(mfrow=c(1,1))
b <- boxplot(mni_sum ~ month, data=obs_pred.v3, plot=0)
boxplot(mni_sum ~ month, data=obs_pred.v3, xlab="Month", names=paste(b$names, "(n=", b$n, ")"),
        las=2,cex.axis=0.75) #This way puts sample size along x-axis

#Produce side by side boxplots for mni_sum and kgs_sum, by covariate
par(mfrow=c(1,1))

for (i in 18:19){
  t <- boxplot(as.matrix(obs_pred.v3[,i]) ~ obs_pred.v3$month*obs_pred.v3$comname, plot=0,
          main=colnames(obs_pred.v3)[i])
  
  boxplot(as.matrix(obs_pred.v3[,i]) ~ obs_pred.v3$month*obs_pred.v3$comname, las=2,
          main=colnames(obs_pred.v3)[i], xlab="Month", cex.axis=0.75)
  
  text(1:length(t$n), t$stats[5,]+1, paste("", t$n), pos=3, offset=0.6, cex=0.75, col=4)
  
}

#Original below - no sample size on plots
#par(mfrow=c(1,2))

#for (i in 18:19){
  #boxplot(as.matrix(obs_pred[,i]) ~ obs_pred$month, las=2,
          #main=colnames(obs_pred)[i])
#}

#par(ask=F)

#Histograms not controlled by any covariates
plot.new()
par(mfrow=c(1,2))
hist(obs_pred.v3$mni_sum,col="grey", border=NA, las=1, breaks=0:130)
hist(obs_pred.v3$kgs_sum,col="grey", border=NA, las=1, breaks=0:15)

output_n <- table(obs_pred.v2$mni_sum)

#Scatterplot of latitude and longitude against mni and kgs consumed - with boxplot in margins
par(mfrow=c(1,1))

sp(obs_pred.v3$mni_sum~obs_pred.v3$latdd,ellipse=FALSE)
sp(obs_pred_unk$mni_sum~obs_pred_unk$londd,ellipse=FALSE)

sp(obs_pred.v3$mni_sum~obs_pred.v3$H)
sp(obs_pred.v3$mni_sum~obs_pred.v3$prey)
sp(obs_pred.v3$mni_sum~obs_pred.v3$guild_obs)
sp(obs_pred.v3$prey~obs_pred.v3$H)
sp(obs_pred.v3$guild_obs~obs_pred.v3$H)
sp(obs_pred.v3$guild_obs~obs_pred.v3$prey)

scatter.smooth(obs_pred.v3$latdd~obs_pred.v3$londd) #scatterplot of lat vs lon with smoother
scatter.smooth(obs_pred.v3$mni_sum~obs_pred.v3$kgs_sum) #
scatter.smooth(obs_pred.v3$mni_sum~obs_pred.v3$H)
scatter.smooth(obs_pred.v3$mni_sum~obs_pred.v3$prey)
scatter.smooth(obs_pred.v3$mni_sum~obs_pred.v3$guild_obs)
#scatterplot(obs_pred$mni_sum, obs_pred$kgs_sum,smooth=FALSE,by.groups = TRUE, groups=obs_pred$latdd)
#scatterplotMatrix(~mni_sum+kgs_sum+londd+latdd+month+comname+season+sex+age+guild_obs+prey, data=obs_pred,smooth=FALSE)

#Create subset of data that has all empty stomach removed factor values = unkown removed
#Remove all rows where factor values = unknown

dim(obs_pred.v3)
table(obs_pred.v3$Epu)
table(obs_pred.v3$sex)
table(obs_pred.v3$age)


obs_pred_unk = obs_pred.v3 %>% filter (Epu != '' & sex !='.' & age != 'unk')


dim(obs_pred_unk)
table(obs_pred_unk$Epu)
table(obs_pred_unk$sex)
table(obs_pred_unk$age)

#find outliers
#dim(obs_pred)
#length(which(obs_pred$mni_sum==87)) #Hg from MAB that has mni_sum=87
#length(which(obs_pred[,18]==87)) #does the same as previous line

#Remove outliers - but first re-run models with truncated dataset (unknowns removed)
dim(obs_pred_unk)
sub_obs_pred <- obs_pred_unk[-c(41,173,257),]
dim(sub_obs_pred)

##MODEL BUILDING - SEE OUTPUT IN 'GAM_model runs.docx' - predicting mni_sum which are discrete counts
#GLM model 1 - family = poisson

summary(one <- glm(mni_sum ~ guild_obs, family = poisson, data=obs_pred_unk, na.action=na.omit))

attributes(one)

par(mfrow=c(1,1))

plot(one)
#disp$xlevels
one$R
anova(one)
j <- aov(mni_sum ~ H, data = obs_pred_unk)
summary(j)
glm.diag.plots(one)

#attributes(disp$linear.predictors)

dispersiontest(one)

#GLM model 2 - family = quasipoisson
summary(two <- glm(mni_sum ~ latdd+londd+latdd*londd+as.factor(guild_obs), family = quasipoisson, data=obs_pred_unk, na.action=na.omit))

attributes(two)

par(mfrow=c(2,2))

plot(two)
#disp$xlevels
two$R
anova(two)
j <- aov(mni_sum ~ londd+as.factor(guild_obs), data = obs_pred_unk)
summary(j)
glm.diag.plots(two)

#attributes(disp$linear.predictors)

dispersiontest(two)

#GAM model 3 - family = poisson - same results as GLM with log link

summary(three <- gam(mni_sum ~ s(latdd)+as.factor(guild_obs),
                    family=poisson(link=log), data=obs_pred_unk, na.action=na.omit))

dispersiontest(three)
plot(three)
plot(three, residuals=TRUE)
gam.check(three,pch=19,cex=.3)

#GAM model 4 - family = quasipoisson - adds smooth terms - GLM doesn't include smooth terms

summary(four <- gam(mni_sum ~ s(londd)+ s(kgs_sum) + prey + s(H),
                         family=quasipoisson(link = "log"), data=obs_pred_unk, na.action=na.omit))

summary(four.nb <- gam(mni_sum ~ s(londd)+s(kgs_sum) + prey + s(H),
                    family=negbin(link=log,theta=3), data=obs_pred_unk, na.action=na.omit))

summary(five <- gam(mni_sum ~ s(latdd) + s(londd)+ti(latdd,londd),
                    family=quasipoisson(link = "log"), data=obs_pred_unk, na.action=na.omit))

summary(six <- gam(mni_sum ~ s(latdd) + s(londd)+as.factor(guild_obs),
                    family=quasipoisson(link = "log"), data=obs_pred_unk, na.action=na.omit))


library(mass)
summary(seven <- glm.nb(mni_sum ~ latdd + londd + latdd*londd + comname+
                      kgs_sum + as.factor(guild_obs) + prey + H,
                      data=obs_pred_unk, na.action=na.omit))

summary(eight <- glm(mni_sum ~ latdd + londd + (latdd*londd) + as.numeric(month)+
                          kgs_sum + as.factor(guild_obs) + prey + comname + H,
                          family="quasipoisson", data=obs_pred_unk, na.action=na.omit))

pearsonRes<-resid(four,type="pearson")
plot(pearsonRes~as.numeric(obs_pred_unk$month))
plot(pearsonRes~seven$fitted)
plot(seven)
Disperson<-sum(pearsonRes^2)/four$df.residual

anova.gam(four)

anova.gam(four.nb)
par(mfrow=c(1,1))
glm.diag.plots(seven)
plot(four.nb)
plot(four, residuals=TRUE)
par(mfrow=c(2,2))
gam.check(four.nb,pch=19,cex=.3)
gam.resid<-sum(residuals(four.nb, type="pearson")^2)/four.nb$df.residual

four$null.deviance
four$deviance
gamdisp.q$edf
gamdisp.q$nsdf #non-smoothed terms degrees of freedom
gamdisp.q$edf1
gamdisp.q$df.residual

anova(two,four,test = "F")
anova(four,six,test = "F")
anova.gam(four,six,test="F")

find<-c(four.nb$fitted.values>100)

#Look at Interaction of predator and other factorial effects on consumption of mni & kgs

par(mfrow=c(1,2))

interaction.plot(
  x.factor = obs_pred_unk$age, #change this to any explanatory variable in the dset
  trace.factor = obs_pred_unk$comname,
  response = obs_pred_unk$mni_sum,
  fun = median,
  ylab = "Median Minimum no. of prey consumed",
  xlab = "Age",
  trace.label = "Predator",
  col = c("#0198f9","#f95801"),
  lty = 1,
  lwd = 3
)

interaction.plot(
  x.factor = obs_pred_unk$age, #change this to any explanatory variable in the dset
  trace.factor = obs_pred_unk$comname,
  response = obs_pred_unk$mni_sum,
  fun = mean,
  ylab = "Mean Minimum no. of prey consumed",
  xlab = "Age",
  trace.label = "Predator",
  col = c("#0198f9","#f95801"),
  lty = 1,
  lwd = 3
)

#Look at effect of predator on lat & lond linear relationship using coplot

coplot(mni_sum ~ kgs_sum | comname, data=obs_pred_unk, rows=2)
coplot(mni_sum ~ kgs_sum | guild_obs, data=obs_pred_unk, rows=2)

coplot(mni_sum ~ guild_obs | comname, data=obs_pred_unk, rows=2)
coplot(mni_sum ~ prey | comname, data=obs_pred_unk, rows=2)

coplot(mni_sum ~ month | comname * Epu, data=obs_pred_unk, rows=2)
coplot(kgs_sum ~ month | comname * Epu, data=obs_pred_unk, rows=2)

coplot(mni_sum ~ londd | comname, data=obs_pred_unk, rows=2)
coplot(mni_sum ~ latdd | comname, data=obs_pred_unk, rows=2)
coplot(latdd ~ londd | comname, data=obs_pred_unk, rows=2)

coplot(mni_sum ~ Epu | comname, data=obs_pred_unk, rows=2)

coplot(mni_sum ~ age | age, data=obs_pred_unk,rows=1)
coplot(mni_sum ~ sex | comname, data=obs_pred_unk,rows=1)



#GLM model 2 - family = quasipoisson to address overdispersion
summary(dispq <- glm(mni_sum ~ comname+londd+latdd, family = quasipoisson, data=obs_pred_unk, na.action=na.omit))

summary(dispq <- glm(mni_sum ~ comname+londd+latdd+as.numeric(month), family = quasipoisson, data=obs_pred_unk, na.action=na.omit))

Anova(dispq)
j <- aov(mni_sum ~ comname+londd+latdd+latdd:londd+comname:londd, data = obs_pred_unk)
summary(j)

par(mfrow=c(2,2))
plot(dispq)
glm.diag.plots(dispq)

#GAM model 3 - family = poisson - same results as GLM with log link

#summary(gamdisp <- gam(mni_sum ~ comname,
#                      family=poisson(link=log), data=obs_pred_unk, na.action=na.omit))

#dispersiontest(gamdisp)
#plot(gamdisp)
#plot(gamdisp, residuals=TRUE)

#GAM model 4 - family = quasipoisson - adds smooth terms - GLM doesn't include smooth terms

summary(gamdisp.q <- gam(mni_sum ~ comname+s(londd)+ti(londd,latdd)+s(latdd)+s(as.numeric(month))+
                           as.factor(guild_obs)+as.factor(prey)+sex,
                      family=quasipoisson(link = "log"), data=obs_pred_unk, na.action=na.omit))

anova.gam(gamdisp.q)
par(mfrow=c(1,2))
plot(gamdisp.q)
par(mfrow=c(2,2))
gam.check(gamdisp.q,pch=19,cex=.3)

summary(gamdisp.q.sub <- gam(mni_sum ~ s(londd)+s(latdd)+s(as.numeric(month))+
                           as.factor(guild_obs)+as.factor(prey),
                         family=quasipoisson(link = "log"), data=obs_pred_unk, na.action=na.omit))

anova.gam(gamdisp.q.sub)
par(mfrow=c(1,2))
plot(gamdisp.q.sub)
par(mfrow=c(2,2))
gam.check(gamdisp.q.sub,pch=19,cex=.3)

#

gamdisp.q$null.deviance
gamdisp.q$deviance
gamdisp.q$edf
gamdisp.q$nsdf #non-smoothed terms degrees of freedom
gamdisp.q$edf1
gamdisp.q$df.residual
plot(gamdisp.q)
plot(gamdisp.q, residuals=TRUE)

#Confirmed that data are overdispered - GAM fits better than GLM - using quasi-poisson
#to account for over-dispersed data, correctly estimated standard error for coefficients

#model 5 - add in month, sex and age to quasi-gam model
summary(gamdisp.q <- gam(mni_sum ~ comname+s(latdd)+s(month),
                         family=quasipoisson(link = "log"), data=sub_obs_pred, na.action=na.omit))

plot(gamdisp.q)
plot(gamdisp.q, residuals=TRUE)

summary(gamdisp.q <- gam(mni_sum ~ comname+Epu+season,
                         family=quasipoisson(link = "log"), data=sub_obs_pred, na.action=na.omit))

plot(gamdisp.q)
plot(gamdisp.q, residuals=TRUE)

summary(dispq <- glm(mni_sum ~ comname+Epu+season, family = quasipoisson, data=sub_obs_pred, na.action=na.omit))
plot(dispq)


summary(gamdisp.q <- gam(mni_sum ~ comname+sex+age,
                         family=quasipoisson(link = "log"), data=sub_obs_pred, na.action=na.omit))

plot(gamdisp.q)
plot(gamdisp.q, residuals=TRUE)

summary(gamdisp.q <- gam(mni_sum ~ comname+s(latdd)+season,
                         family=quasipoisson(link = "log"), data=sub_obs_pred, na.action=na.omit))

plot(gamdisp.q)
plot(gamdisp.q, residuals=TRUE)

summary(gamdisp.q <- gam(mni_sum ~ comname+s(latdd)+s(month)+sex,
                         family=quasipoisson(link = "log"), data=sub_obs_pred, na.action=na.omit))

plot(gamdisp.q)
plot(gamdisp.q, residuals=TRUE)

summary(gamdisp.q <- gam(mni_sum ~ comname+s(latdd)+s(month)+sex+age,
                         family=quasipoisson(link = "log"), data=sub_obs_pred, na.action=na.omit))

plot(gamdisp.q)
plot(gamdisp.q, residuals=TRUE)

summary(gamdisp.q <- gam(mni_sum ~ comname+s(latdd)+season+sex,
                         family=quasipoisson(link = "log"), data=sub_obs_pred, na.action=na.omit))

plot(gamdisp.q)
plot(gamdisp.q, residuals=TRUE)

## ALL 3 MODELS BELOW HAVE COMNAME, LATDD AND SEASON AS IMPORTANT VARIABLES. ALL MODELS PREFER
## LATDD OVER CATEGORICAL EPU VARIABLE AND CATEGORICAL SEASON VS MONTH VARIABLE
## HARBOR SEAL, SNE/NMAB, AND SUMMER SEASON HAVE HIGHER PREY ABUNDANCE CONSUMED.
## THIS PATTERN PERSISTS AMONG ALL 3 MODELS (I.E. REGARDLESS OF OUTLIERS AND UNKNOWNS)
## ALL MODELS ARE STILL OVERDISPERSED (<30% OF DEVIANCE EXPLAINED), INDICATING:
## MISSING COVARIATES, NATURAL VARIABILITY OR MODEL MIS-SPECIICATION
## CONSIDER ADDING RANDOM EFFECT IF OVERDISPERSION PERSISTS

## NEXT STEPS:
## INCLUDE NUMBER OF GUILDS FOUND AND NUMBER OF PREY FOUND AS COVARIATES
## INCLUDE INTERACTION TERM FOR LAT&LON
## EVALUATE POOLING PUPS WITH YOY AND JUVENILES WITH ADULTS
## THEN MODEL KGS_SUM (BIOMASS CONSUMED) BY SAME COVARIATES
## CALCULATE DIVERSITY INDEX FOR EACH STOMACH AND MODEL THAT AS A FUNCTIO OF COVARIATES

## BEST MODEL SO FAR WITH LOWEST OVERDISPERSION BUT STILL HIGH - DSET HAS UNK'S AND OUTLIERS REMOVED
# HAS 21.9% DEVIANCE EXPLAINED. N=301
# DISPERSION = 15.504

summary(gamdisp.q <- gam(mni_sum ~ comname+s(latdd)+season+sex+age,
                         family=quasipoisson(link = "log"), data=sub_obs_pred, 
                         na.action=na.omit))

summary(gamdisp.q <- gam(mni_sum ~ comname + latdd + s(latdd) + londd + latdd:londd,
                         family=quasipoisson(link = "log"), data=sub_obs_pred, 
                         na.action=na.omit))

summary(gamdisp.q <- gam(mni_sum ~ comname + latdd + s(latdd, by=comname,bs = "fs"),
                         family=quasipoisson(link = "log"), data=sub_obs_pred, 
                         na.action=na.omit))


summary(gamdisp.q <- gam(mni_sum ~ comname+s(latdd)+season+sex+age,
                         family=quasipoisson(link = "log"), data=sub_obs_pred, 
                         method="REML", na.action=na.omit))


par(mfrow=c(1,2))
plot(gamdisp.q)
plot(gamdisp.q, residuals=TRUE)

#SAME MODEL BUT ONLY UNK'S REMOVED - INCLUDES OUTLIERS
#HAS 23.7% DEVIANCE EXPLAINEd WHEN OUTLIERS ARE INCLUDED! N=304
#DISPERSION = 17.421 - OVERDISPERSION INCREASED BY 1.917 (MARGINAL)

summary(gamdisp.q <- gam(mni_sum ~ comname+latdd+s(latdd)+season+sex+age,
                           family=quasipoisson(link = "log"), data=obs_pred_unk, na.action=na.omit,
                           select=TRUE))

summary(gamdisp.q.a <- gam(mni_sum ~ comname+latdd+s(latdd)+season+sex+age,
                         family=quasipoisson(link = "log"), data=obs_pred_unk, na.action=na.omit,
                         method="REML",select=TRUE))

summary(gamdisp.q.b <- gam(mni_sum ~ comname+latdd+s(latdd,bs="cr")+season+sex+age,
                         family=quasipoisson(link = "log"), data=obs_pred_unk, na.action=na.omit,
                         method="REML",select=TRUE))

summary(gamdisp.q.1 <- gam(mni_sum ~ comname + s(londd, by=comname,bs = "fs")+
                             season + sex + as.factor(guild_obs) + as.factor(prey),
                         family=quasipoisson(link = "log"), data=obs_pred_unk,
                         selection=TRUE, na.action=na.omit))

summary(gamdisp.q.2 <- gam(mni_sum ~ londd + latdd + s(latdd, by=comname,bs = "fs") +
                             sex + as.factor(guild_obs) + as.factor(prey),
                           family=quasipoisson(link = "log"), data=obs_pred_unk,
                          selection=TRUE, na.action=na.omit))

summary(gamdisp.q.3 <- gam(mni_sum ~ londd + latdd + season + 
                             sex + as.factor(guild_obs) + as.factor(prey),
                           family=quasipoisson(link = "log"), data=obs_pred_unk,
                           selection=TRUE, na.action=na.omit))

summary(gamdisp.q.4 <- gam(mni_sum ~ londd + latdd + season + comname +
                             sex + as.factor(guild_obs) + as.factor(prey),
                           family=quasipoisson(link = "log"), data=obs_pred_unk,
                           selection=TRUE, na.action=na.omit))

summary(gamdisp.q.5 <- gam(mni_sum ~ as.factor(guild_obs)+s(londd)+s(month)+as.factor(prey)+
                            sex+s(latdd)+comname,
                           family=quasipoisson(link = "log"), data=obs_pred_unk,
                           selection=TRUE, na.action=na.omit))

anova(gamdisp.q.5)

attributes(gamdisp.q.1)
gamdisp.q.1$null.deviance
gamdisp.q.1$deviance
gamdisp.q.1$gcv.ubre
gamdisp.q.1$var.summary
gamdisp.q.1$linear.predictors
gamdisp.q.1$scale
gamdisp.q.1$df.null
gamdisp.q.1$edf
gamdisp.q.1$nsdf #non-smoothed terms degrees of freedom
gamdisp.q.1$edf1
gamdisp.q.5$df.residual


plot(gamdisp.q.1)
plot(gamdisp.q.5, residuals=TRUE)

anova(gamdisp.q.2)
plot(gamdisp.q.2)
plot(gamdisp.q.2, residuals=TRUE)

par(mfrow=c(1,2))
gam.check(gamdisp.q.5,pch=19,cex=.3)
gam.check(gamdisp.q.1,pch=19,cex=.3)
gam.check(gamdisp.q.3,pch=19,cex=.3)
#s(latdd, by=comname,bs = "fs")

#SAME MODEL BUT WITH ORIGINAL DSET - INCLUDES UNK'S AND OUTLIERS
#HAS  21.6% DEVIANCE EXPLAINED (N=321)
#OVERDISPERSION = 18.406

summary(gamdisp.q <- gam(mni_sum ~ comname+s(latdd)+season+sex+age,
                         family=quasipoisson(link = "log"), data=obs_pred, na.action=na.omit))

plot(gamdisp.q)
plot(gamdisp.q, residuals=TRUE)

## INLCUDE LONDD
## THIS IS NOW THE BEST MODEL! 
## HAS 27.2% DEVIANCE EXPLAINED - EXLUDES UNK'S BUT OUTLIERS STILL IN DSET - N=304
## OVERDISPERSION STILL ABOUT THE SAME 16.028

summary(gamdisp.q <- gam(mni_sum ~ comname+s(latdd)+s(londd)+s(month)+sex+age,
                         family=quasipoisson(link = "log"), data=obs_pred_unk, na.action=na.omit))

par(mfrow=c(1,3))
plot(gamdisp.q)
plot(gamdisp.q, residuals=TRUE)

#WITHOUT SMOOTHERS
summary(gamdisp.q <- gam(mni_sum ~ comname+latdd+londd+month+sex+age,
                         family=quasipoisson(link = "log"), data=obs_pred_unk, na.action=na.omit))

par(mfrow=c(1,3))
plot(gamdisp.q)
plot(gamdisp.q, residuals=TRUE)

#GLM VERSION OF GAM MODEL ABOVE
#HAS 17.86% DEVIANCE EXPLAINED
# OVERDISPERSION = 18.57
summary(dispq <- glm(mni_sum ~ comname+latdd+londd+month+sex+age, 
                     family = quasipoisson, data=obs_pred_unk, na.action=na.omit))

par(mfrow=c(2,2))
plot(dispq)

#Look at univariate models
summary(dispq <- glm(mni_sum ~ comname, family = quasipoisson, data=obs_pred_unk, na.action=na.omit))
plot(dispq)

summary(dispq <- glm(mni_sum ~ sex, family = quasipoisson, data=obs_pred_unk, na.action=na.omit))
plot(dispq)

summary(dispq <- glm(mni_sum ~ age, family = quasipoisson, data=obs_pred_unk, na.action=na.omit))
plot(dispq)

summary(dispq <- glm(mni_sum ~ Epu, family = quasipoisson, data=obs_pred_unk, na.action=na.omit))
plot(dispq)
anova(dispq)
glm.diag.plots(dispq)

summary(dispq <- glm(mni_sum ~ latdd, family = quasipoisson, data=obs_pred_unk, na.action=na.omit))
plot(dispq)

summary(dispq <- glm(mni_sum ~ londd, family = quasipoisson, data=obs_pred_unk, na.action=na.omit))
plot(dispq)

summary(dispq <- glm(mni_sum ~ latdd+londd, family = quasipoisson, data=obs_pred_unk, na.action=na.omit))
plot(dispq)

summary(gamdisp.q <- gam(mni_sum ~ s(latdd)+s(londd),
                         family=quasipoisson(link = "log"), data=obs_pred_unk, na.action=na.omit))

plot(gamdisp.q)
plot(gamdisp.q, residuals=TRUE)


###################################################################################
#Very early explorations below - use output from above scripts
#Explore some modeling
#For season, epu, age, sex effects on mni and wgtkgs

#Subset harbor seal and gray seal into two d-set for now

Pv.obs.pred=obs_pred[c(obs_pred$comname=="Harbor Seal"),]
Hg.obs.pred=obs_pred[c(obs_pred$comname=="Gray Seal"),]
Pv.obs.pred.2=new_obs_pred[c(new_obs_pred$comname=="Harbor Seal"),] #Transformed
Hg.obs.pred.2=new_obs_pred[c(new_obs_pred$comname=="Gray Seal"),] #Transformed

#Harbor Seal models
junkpv <- glm(mni_sum ~  sex+age, 
              family=quasi(link=log, var=mu), data=Pv.obs.pred, na.action=na.omit, 
              control=glm.control(maxit=50))


junkpv <- glm(mni_sum ~  sex, 
                     family=quasi(link=log, var=mu), data=Pv.obs.pred.2, na.action=na.omit, 
                     control=glm.control(maxit=50))

junkpv <- glm(kgs_sum ~  sex, 
              family=quasi(link=log, var=mu), data=Pv.obs.pred, na.action=na.omit, 
              control=glm.control(maxit=50))


junkpv <- glm(kgs_sum ~  sex, 
              family=quasi(link=log, var=mu), data=Pv.obs.pred.2, na.action=na.omit, 
              control=glm.control(maxit=50))

attributes(junkpv)
summary(junkpv)
plot(junkpv)
#plot(junkpv, resid=T, se=T)
anova(junkpv, test="F")
AIC(junkpv)
#stepAIC(junkpv)
#logLik(junkpv)

#Gray Seal models
junkhg <- glm(mni_sum ~ age, 
              family=quasi(link=log, var=mu), data=Hg.obs.pred, na.action=na.omit, 
              control=glm.control(maxit=50))


junkhg <- glm(mni_sum ~ sex, 
              family=quasi(link=log, var=mu), data=Hg.obs.pred.2, na.action=na.omit, 
              control=glm.control(maxit=50))

junkhg <- glm(kgs_sum ~ age, 
              family=quasi(link=log, var=mu), data=Hg.obs.pred, na.action=na.omit, 
              control=glm.control(maxit=50))

junkhg <- glm(kgs_sum ~ sex, 
              family=quasi(link=log, var=mu), data=Hg.obs.pred.2, na.action=na.omit, 
              control=glm.control(maxit=50))

attributes(junkhg)
summary(junkhg)
plot(junkhg)
#plot(junkhg, resid=T, se=T)
anova(junkhg, test="F")
AIC(junkhg)
#stepAIC(junkhg)
#logLik(junkhg)


#Both predators as a covariate predicting mni and wgtkgs
#GLM
junkpred_mni <- glm(mni_sum ~ comname, 
                    family=quasi(link=log, var=mu), data=new_obs_pred, na.action=na.omit, 
                    control=glm.control(maxit=50))

junkpred_mni <- glm(mni_sum ~ comname+latdd+month+sex+age, 
                    family=quasi(link=log, var=mu), data=new_obs_pred, na.action=na.omit, 
                    control=glm.control(maxit=50))

junkpred_kgs <- glm(kgs_sum ~ comname, 
              family=quasi(link=log, var=mu), data=new_obs_pred, na.action=na.omit, 
              control=glm.control(maxit=50))

attributes(junkpred_mni)
attributes(junkpred_kgs)

summary(junkpred_mni)
summary(junkpred_kgs)

par(mfrow=c(2,2)) #page will have 2 row with 2 columns

plot(junkpred_mni)
plot(junkpred_kgs)

#GAM
junkpred_mni.2 <- gam(mni_sum ~ comname+s(latdd)+s(month)+sex+age,
                      family=quasipoisson(link = "log"), data=obs_pred, na.action=na.omit)

junkpred_mni.2 <- gam(mni_sum ~ comname+s(latdd)+s(month)+sex+age,
                family=poisson(link=log), data=obs_pred, na.action=na.omit)
                      
                      #+s(SST.Final)+(latzone)+(NETCODE)+
               # s(HDROPLEN)+s(btm.dpth)+(seas2)+s(codms)+s(TOWSPEED)+s(GTONS)+(species)+(EXCLUSD),
              
#summary(warnings())
attributes(junkpred_mni.2)
summary(junkpred_mni.2)
plot(junkpred_mni.2,residuals=FALSE)
plot(junkpred_mni.2,residuals=TRUE)
plot(junkpred_mni.2,terms="latdd")
plot(junkpred_mni.2,terms="scale")
junkpred_mni.2$xlevels
junkpred_mni.2$terms

junkpred.kgs <- glm(kgs_sum ~ comname+sex, 
              family=quasi(link=log, var=mu), data=new_obs_pred, na.action=na.omit, 
              control=glm.control(maxit=50))

junkpred.mni <- glm(mni_sum ~ comname+sex, 
                family=quasi(link=log, var=mu), data=new_obs_pred, na.action=na.omit, 
                control=glm.control(maxit=50))

attributes(junkpred)

summary(junkpred.kgs)
summary(junkpred.mni)

plot(junkpred.kgs)
plot(junkpred.mni)
#plot(junkhg, resid=T, se=T)
anova(junkhg, test="F")
AIC(junkhg)
#stepAIC(junkhg)
#logLik(junkhg)


#Look at season and epu effects with both predators in the model - transformed mni & kgs

junkpred.kgs <- glm(kgs_sum ~ comname+season, 
                    family=quasi(link=log, var=mu), data=new_obs_pred, na.action=na.omit, 
                    control=glm.control(maxit=50))

junkpred.mni <- glm(mni_sum ~ comname+season, 
                    family=quasi(link=log, var=mu), data=new_obs_pred, na.action=na.omit, 
                    control=glm.control(maxit=50))

attributes(junkpred)

summary(junkpred.kgs)
summary(junkpred.mni)

plot(junkpred.kgs)
plot(junkpred.mni)
#plot(junkhg, resid=T, se=T)
anova(junkhg, test="F")
AIC(junkhg)
#stepAIC(junkhg)
#logLik(junkhg)

par(mar = c(4.0, 4.0, 1, 0))
par(ask = T)

